----------
Exceptions
----------

.. currentmodule:: oslo_messaging

.. autoexception:: ClientSendError
.. autoexception:: DriverLoadFailure
.. autoexception:: ExecutorLoadFailure
.. autoexception:: InvalidTransportURL
.. autoexception:: MessagingException
.. autoexception:: MessagingTimeout
.. autoexception:: MessagingServerError
.. autoexception:: NoSuchMethod
.. autoexception:: RPCDispatcherError
.. autoexception:: RPCVersionCapError
.. autoexception:: ServerListenError
.. autoexception:: UnsupportedVersion
